@@ -36,8 +36,7 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 
-$cgextensions = cms_join_path($gCms->config['root_path'],'modules',
-			      'CGExtensions','CGExtensions.module.php');
+$cgextensions = cms_join_path($gCms->config['root_path'],'modules','CGExtensions','CGExtensions.module.php');
 if( !is_readable( $cgextensions ) )
 {
   echo '<h1><font color="red">ERROR: The CGExtensions module could not be found.</font></h1>';
@@ -70,6 +69,8 @@ final class CGCalendar extends CGExtensions
   var $fields_table_name;
   var $event_field_values_table_name;
   var $admin_tools_loaded;
+  static $_cached_categories;
+  static $_cached_fields;
   
   function __construct()
   {
@@ -92,21 +93,19 @@ final class CGCalendar extends CGExtensions
 
 	$this->SetParameterType('display',CLEAN_STRING);
 	$this->SetParameterType('category',CLEAN_STRING);
+	$this->SetParameterType('week',CLEAN_INT);
 	$this->SetParameterType('month',CLEAN_INT);
 	$this->SetParameterType('year',CLEAN_INT);
-	$this->SetParameterType('first_day_of_week',CLEAN_INT);
+	$this->SetParameterType('date',CLEAN_STRING);
 	$this->SetParameterType('use_session',CLEAN_STRING);
 	$this->SetParameterType('inline',CLEAN_INT);
 	$this->SetParameterType('reverse',CLEAN_STRING);
+	$this->SetParameterType('pastitems',CLEAN_INT);
 	$this->SetParameterType('detailpage',CLEAN_STRING);
-	$this->SetParameterType('columns',CLEAN_INT);
-	$this->SetParameterType('columnstyle',CLEAN_STRING);
-	$this->SetParameterType('currentcolumn',CLEAN_INT);
 
 	$this->SetParameterType('page',CLEAN_INT);
 	$this->SetParameterType('event_id',CLEAN_INT);
 	$this->SetParameterType('limit',CLEAN_INT);
-	$this->SetParameterType('detail',CLEAN_STRING);
 	$this->SetParameterType('calendartemplate',CLEAN_STRING);
 	$this->SetParameterType('eventtemplate',CLEAN_STRING);
 	$this->SetParameterType('listtemplate',CLEAN_STRING);
@@ -121,23 +120,15 @@ final class CGCalendar extends CGExtensions
 	$this->SetParameterType('editpage',CLEAN_INT);
 
 	$this->SetParameterType('unique_only',CLEAN_INT);
-
 	$this->SetParameterType('return_id',CLEAN_INT);
-	$this->SetParameterType('return_link',CLEAN_STRING);
-
 	$this->SetParameterType('show_ical',CLEAN_STRING);
       
 	$this->SetParameterType(CLEAN_REGEXP.'/cal_.*/',CLEAN_STRING);
 
 	$this->RegisterRoute('/'.$this->GetPreference('url_prefix','calendar').'\/(?P<returnid>[0-9]+)\/(?P<event_id>[0-9]+)-.*$/',
 						 array('action'=>'default','display'=>'event'));
-
-	if( version_compare(CMS_VERSION,'1.10-beta0') < 0 ) {
-	  $this->InitializeAdmin();
-	}
   }
-  
-
+ 
   function InitializeAdmin()
   {
 	$this->CreateParameter('myeventstemplate','',$this->Lang('help_param_myeventstemplate'));
@@ -147,19 +138,19 @@ final class CGCalendar extends CGExtensions
 
   function InitializeFrontend() { $this->SetParameters(); }
   function GetName() { return 'CGCalendar'; }
-  function GetAuthor() { return 'Rob Allen/Calguy1000/Morten Poulsen'; }
-  function GetAuthorEmail() { return 'morten@poulsen.org/calguy1000@hotmail.com'; }
+  function GetAuthor() { return 'Robert Campbell'; }
+  function GetAuthorEmail() { return 'calguy1000@gmail.com'; }
   function IsPluginModule() { return true; }
   function HasAdmin() { return true; }  
   function GetEventDescription( $eventname ) { return $this->lang('eventdesc-' . $eventname); }
   function GetEventHelp( $eventname ) {	return $this->lang('eventhelp-' . $eventname); }
-  function GetVersion() { return '1.10.4'; }
-  function GetDependencies() { return array('CGExtensions'=>'1.32'); }
+  function GetVersion() { return '1.11.4.1'; }
+  function GetDependencies() { return array('CGExtensions'=>'1.32.3'); }
   function GetDescription($lang = 'en_US') { return $this->Lang("description"); }
   function GetAdminDescription() { return $this->Lang('cal_description'); }
   function GetAdminSection() { return 'content'; }
   function GetHelp () { return file_get_contents(__DIR__.'/help.inc'); }
-  function MinimumCMSVersion() { return '1.11.3'; }
+  function MinimumCMSVersion() { return '1.11.8'; }
   function GetChangeLog() { return file_get_contents(__DIR__.'/changelog.inc'); }
   function InstallPostMessage() { return $this->Lang('install_postmessage'); }
   function UninstallPreMessage() { return $this->Lang('areyousure_uninstall'); }
@@ -184,18 +175,25 @@ final class CGCalendar extends CGExtensions
 	  $this->CheckPermission('Modify Templates');
   }
 
-  function GetEvent($event_id)
+  protected function GetEvent($event_id,$uid = -1)
   {
-	$db = $this->GetDb(); /* @var $db ADOConnection */
+	$rs = null;
+
+	if( $event_id > 0 ) {
+	  $db = $this->GetDb(); /* @var $db ADOConnection */
+	  $sql = 'SELECT * FROM ' . $this->events_table_name .' WHERE event_id = ?';
+	  $parms = array($event_id);
+	  if( $uid != -1 && $uid != 0 ) {
+		$sql .= ' AND event_created_by = ?';
+		$parms[] = $uid;
+	  }
+	  $rs = $db->Execute($sql,$parms);
+	}
 
-	$sql = 'SELECT * FROM ' . $this->events_table_name .' WHERE event_id = ?';
-	$rs = $db->Execute($sql,array($event_id));
 	if($rs && $rs->RecordCount() > 0) {
 	  $result = $rs->FetchRow();
 	  $result['event_date_start_ut'] = $db->UnixTimeStamp($result['event_date_start']);
-	  if( is_null($result['event_date_end']) || $result['event_date_end'] == '0000-00-00 00:00:00') {
-		$result['event_date_end'] = NULL;
-	  }
+	  if( is_null($result['event_date_end']) || $result['event_date_end'] == '0000-00-00 00:00:00') $result['event_date_end'] = NULL;
 	  $result['event_date_end_ut'] = $db->UnixTimeStamp($result['event_date_end']);
 	  if( is_null($result['event_date_recur_end']) || $result['event_date_recur_end'] == '0000-00-00 00:00:00' ) {
 		$result['event_date_recur_end'] = NULL;
@@ -235,12 +233,8 @@ final class CGCalendar extends CGExtensions
 	  $em = date('i',$result['event_date_end_ut']);
 	  $result['all_day_event'] = 0;
 	  $result['alt_end_date'] = 0;
-	  if( $sh == 0 && $sm == 0 && $eh == 23 && $em == 59 ) {
-		$result['all_day_event'] = 1;
-	  }
-	  if( $sd != $ed ) {
-		$result['alt_end_date'] = 1;
-	  }
+	  if( $sh == 0 && $sm == 0 && $eh == 23 && $em == 59 ) $result['all_day_event'] = 1;
+	  if( $sd != $ed ) $result['alt_end_date'] = 1;
 	}
 	else {
 	  // create an empty record
@@ -274,8 +268,7 @@ final class CGCalendar extends CGExtensions
 	return $result;
   }
 
-
-  function GetEventFromParams(&$event,$params,$is_edit = false)
+  protected function GetEventFromParams(&$event,$params,$is_edit = false)
   {
 	  $db = $this->GetDb();
 	  if( isset($params['event_id']) )  $event['event_id'] =  (int)$params['event_id'];
@@ -301,13 +294,16 @@ final class CGCalendar extends CGExtensions
 		if( !$all_day_event ) {
 		  $start_hour = $params['startdate_Hour'];
 		  $start_minute = $params['startdate_Minute'];
-		  if( isset($params['startdate_Meridian']) && $params['startdate_Meridian'] == 'pm' &&
-			  $start_hour < 12) {
-			$start_hour += 12;
+		  if( isset($params['startdate_Meridian']) ) {
+			if( $params['startdate_Meridian'] == 'am' && $start_hour >= 12 ) {
+			  $start_hour -= 12;
+			}
+			else if( $params['startdate_Meridian'] == 'pm' && $start_hour < 12 ) {
+			  $start_hour += 12;
+			}
 		  }
 		}
-		$event['event_date_start_ut'] = mktime($start_hour,$start_minute,0,
-											   $params['startdate_Month'],$params['startdate_Day'],
+		$event['event_date_start_ut'] = mktime($start_hour,$start_minute,0,$params['startdate_Month'],$params['startdate_Day'],
 											   $params['startdate_Year']);
 		$event['event_date_start'] = $db->DbTimeStamp($event['event_date_start_ut']);
 	  }
@@ -323,9 +319,10 @@ final class CGCalendar extends CGExtensions
 		if( !$all_day_event ) {
 		  $end_hour = $params['enddate_Hour'];
 		  $end_minute = $params['enddate_Minute'];
-
-		  if( isset($params['enddate_Meridian']) && $params['enddate_Meridian'] == 'pm' &&
-			  $end_hour < 12 ) {
+		  if( $params['enddate_Meridian'] == 'am' && $end_hour >= 12 ) {
+			$end_hour -= 12;
+		  }
+		  else if( $params['enddate_Meridian'] == 'pm' && $end_hour < 12 ) {
 			$end_hour += 12;
 		  }
 		}
@@ -334,13 +331,11 @@ final class CGCalendar extends CGExtensions
 		$end_day = $params['enddate_Day'];
 		$end_year = $params['enddate_Year'];
 
-		$event['event_date_end_ut'] = mktime($end_hour,$end_minute,0,
-											 $end_month,$end_day,$end_year);
+		$event['event_date_end_ut'] = mktime($end_hour,$end_minute,0,$end_month,$end_day,$end_year);
 		$event['event_date_end'] = $db->DbTimeStamp($event['event_date_end_ut']);
 	  }
 	  else if( isset($params['all_day_event']) && !isset($params['enddate_valid']) ) {
-		$event['event_date_end_ut'] = mktime($end_hour,$end_minute,0,
-											 $end_month,$end_day,$end_year);
+		$event['event_date_end_ut'] = mktime($end_hour,$end_minute,0,$end_month,$end_day,$end_year);
 		$event['event_date_end'] = $db->DbTimeStamp($event['event_date_end_ut']);
 	  }
 
@@ -379,28 +374,16 @@ final class CGCalendar extends CGExtensions
 	  }
   }
 
-
-  function GetCategories($order_by='category_order, category_name')
+  function GetCategories()
   {
-      $db = $this->GetDb(); /* @var $db ADOConnection */
+	if( !is_array(self::$_cached_categories) ) {
+      $db = $this->GetDb();
       $categories_table_name = $this->categories_table_name;
-      $sql = "SELECT * FROM $categories_table_name";
-      if($order_by != '') $sql .= " ORDER BY $order_by";
-	  
-      $result = array();
-      $rs = $db->Execute($sql);
-      if($rs && $rs->RecordCount() > 0)
-		$result = $rs->GetArray();
-      return $result;
-  }
+      $sql = "SELECT * FROM $categories_table_name ORDER BY category_order, category_name";
 
-  function GetCategoryName($id)
-  {
-	$db = $this->GetDb();
-	$sql = 'SELECT category_name FROM '.$this->categories_table_name.'
-             WHERE category_id = ?';
-	$name = $db->GetOne($sql,array($id));
-	return $name;
+	  self::$_cached_categories = $db->GetArray($sql);
+	}
+	return self::$_cached_categories;
   }
 
   function AllowAccess($permission='Modify Calendar')
@@ -415,9 +398,7 @@ final class CGCalendar extends CGExtensions
 
   function LoadAdmin()
   {
-	if( $this->admin_tools_loaded === false ) {
-	  require_once('functions.admin_tools.php');
-	}
+	if( $this->admin_tools_loaded === false ) require_once('functions.admin_tools.php');
   }
 
   function AdminDisplayCategories($id, &$parameters, $returnid)
@@ -434,71 +415,43 @@ final class CGCalendar extends CGExtensions
 
   function GetFields()
   {
-    $db = $this->GetDb(); /* @var $db ADOConnection */
-    $fields_table_name = $this->fields_table_name;
-	$sql = "SELECT * FROM $fields_table_name ORDER BY field_name";
+	if( !is_array(self::$_cached_fields) ) {
+	  self::$_cached_fields = array();
 
-	$result = array();
-	$rs = $db->Execute($sql);
-	if($rs && $rs->RecordCount() > 0) {
-	  $result = $rs->GetArray();
-	  if( is_array($result) && count($result) ) {
-		foreach( $result as &$one ) {
-		  if( $one['field_extra'] != '' ) {
-			$one['field_extra'] = unserialize($one['field_extra']);
+	  $db = $this->GetDb(); /* @var $db ADOConnection */
+	  $fields_table_name = $this->fields_table_name;
+	  $sql = "SELECT * FROM $fields_table_name ORDER BY field_order,field_name";
+
+	  $result = array();
+	  $rs = $db->Execute($sql);
+	  if($rs && $rs->RecordCount() > 0) {
+		$result = $rs->GetArray();
+		if( is_array($result) && count($result) ) {
+		  foreach( $result as &$one ) {
+			if( $one['field_extra'] != '' ) $one['field_extra'] = unserialize($one['field_extra']);
 		  }
 		}
+		self::$_cached_fields = $result;
 	  }
 	}
-	return $result;		
+	return self::$_cached_fields;
   }
 
-  function AdminDeleteField($field_oldname)
-  {
-	$db = $this->GetDb(); /* @var $db ADOConnection */
-	$fields_table_name = $this->fields_table_name;
-	$event_field_values_table_name = $this->event_field_values_table_name;
-	  
-	$sql = "DELETE FROM $$event_field_values_table_name where field_name='$field_oldname'";
-	$db->Execute($sql);
-		
-	$sql = "DELETE FROM $fields_table_name where field_name='$field_oldname'";
-	$db->Execute($sql);
-  }
-	
-  function AdminAddField($field_newname,$field_type = 0,$field_searchable = 0,$field_extra = '')
-  {
-	$db = $this->GetDb(); /* @var $db ADOConnection */
-	$sql = 'INSERT INTO ' . $this->fields_table_name . '
-            (field_name,field_type,field_searchable,field_extra)
-            VALUES (?,?,?,?)';
-	if( $field_extra ) $field_extra = serialize($field_extra);
-	$db->Execute($sql,array($field_newname,$field_type,$field_searchable,$field_extra));
-  }
-	
-  function AdminUpdateField($field_oldname,$field_newname,$field_type = 0,$field_searchable = 0,$field_extra = '')
-  {
-      $db = $this->GetDb(); /* @var $db ADOConnection */
-
-      $sql = 'UPDATE ' . $this->fields_table_name . '
-                 SET field_name = ?, field_type = ?, field_searchable = ?, field_extra = ?
-               WHERE field_name = ?';
-	  if( $field_extra ) $field_extra = serialize($field_extra);
-      $db->Execute($sql,array($field_newname, $field_type, $field_searchable, $field_extra, $field_oldname));
-      $sql = 'UPDATE ' . $this->event_field_values_table_name . ' SET field_name = ? WHERE field_name = ?';
-      $db->Execute($sql,array($field_newname, $field_oldname));
-  }
-	
   function GetDayNames()
   {
-      $day_names[0] = $this->Lang('cal_sunday');
-      $day_names[1] = $this->Lang('cal_monday');
-      $day_names[2] = $this->Lang('cal_tuesday');
-      $day_names[3] = $this->Lang('cal_wednesday');
-      $day_names[4] = $this->Lang('cal_thursday');
-      $day_names[5] = $this->Lang('cal_friday');
-      $day_names[6] = $this->Lang('cal_saturday');
-      return $day_names;
+	$day_names[0] = $this->Lang('cal_sunday');
+	$day_names[1] = $this->Lang('cal_monday');
+	$day_names[2] = $this->Lang('cal_tuesday');
+	$day_names[3] = $this->Lang('cal_wednesday');
+	$day_names[4] = $this->Lang('cal_thursday');
+	$day_names[5] = $this->Lang('cal_friday');
+	$day_names[6] = $this->Lang('cal_saturday');
+
+	if($this->GetPreference('firstdayofweek',1)) {
+	  $first = array_shift($day_names);
+	  $day_names[] = $first;
+	}
+	return $day_names;
   }
 
   function GetDayShortNames()
@@ -510,6 +463,11 @@ final class CGCalendar extends CGExtensions
       $day_short_names[4] = $this->Lang('cal_thurs');
       $day_short_names[5] = $this->Lang('cal_fri');
       $day_short_names[6] = $this->Lang('cal_sat');
+
+	  if($this->GetPreference('firstdayofweek',1)) {
+		$first = array_shift($day_short_names);
+		$day_short_names[] = $first;
+	  }
       return $day_short_names;
   }
 
@@ -549,6 +507,8 @@ final class CGCalendar extends CGExtensions
 
       $lang['details'] = $this->Lang('cal_details');
       $lang['return'] = $this->Lang('cal_return');
+	  $lang['current'] = $this->Lang('cal_current');
+	  $lang['from'] = $this->Lang('cal_from');
       $lang['to'] = $this->Lang('cal_to');
       $lang['next'] = $this->Lang('cal_next');
       $lang['prev'] = $this->Lang('cal_prev');
@@ -585,8 +545,7 @@ final class CGCalendar extends CGExtensions
 		
   function SearchResult($returnid, $event_id, $attr = '')
   {
-      $result = array();
-		  
+      $result = array();	  
       if( $attr != 'event') return $result;
 		  
       $db = $this->GetDb();
@@ -596,25 +555,18 @@ final class CGCalendar extends CGExtensions
       $result[0] = $this->GetFriendlyName();
       $result[1] = $title;
 
-      $titleSEO = preg_replace("/[^\w-]+/", "-", $title);
+      $titleSEO = munge_string_to_url($title);
       $destpage = $this->GetPreference('defaultcalendarpage',-1);
       $destpage=$destpage!=-1?$destpage:$returnid;
       $destpage=$detailpage!=''?$detailpage:$destpage;
       $prettyurl = sprintf($this->GetPreference('url_prefix','calendar')."/%d/%d-%s",
-			   $destpage,
-			   $event_id,
-			   $titleSEO);
+						   $destpage,$event_id,$titleSEO);
       $result[2] = $this->CreateLink($id,'default',$destpage,'',
-				     array('event_id'=>$event_id,
-					   'display'=>'event',
-					   'lang'=>$module->curlang,
-					   'detailpage'=>$destpage,
-					   'return_id'=>$returnid),
-				     '', true, '', '', $prettyurl);
+				     array('event_id'=>$event_id,'display'=>'event','detailpage'=>$destpage,'return_id'=>$returnid),
+									 '', true, '', '', $prettyurl);
       return $result;
   }
-
-		
+	
   function SearchReindex(&$module)
   {
       $db = $this->GetDb();
@@ -628,8 +580,7 @@ final class CGCalendar extends CGExtensions
                   WHERE fv.event_id = ?';
   
       while ($dbr && !$dbr->EOF) {
-		$text = $dbr->fields['event_title'].' '.$dbr->fields['event_summary'].' '.
-		  $dbr->fields['event_details'];
+		$text = $dbr->fields['event_title'].' '.$dbr->fields['event_summary'].' '.$dbr->fields['event_details'];
 
 		$morewords = $db->GetCol($fquery,array($dbr->fields['event_id']));
 		if( $morewords ) $text .= ' '.implode(' ',$morewords);
@@ -640,12 +591,9 @@ final class CGCalendar extends CGExtensions
 
   function ToAbbreviatedWeekdays($data)
   {
-	if( !is_array($data) ) {
-	  $data = explode(',',$data);
-	}
+	if( !is_array($data) ) $data = explode(',',$data);
 
-	$weekdays = array(
-					  0=>'sunday',
+	$weekdays = array(0=>'sunday',
 					  1=>'monday',
 					  2=>'tuesday',
 					  3=>'wednesday',
@@ -670,6 +618,27 @@ final class CGCalendar extends CGExtensions
 	return $iCal;       
   }
 	
+  function GetCategoryNames($category_ids)
+  {
+	if( !is_array($category_ids) && (int)$category_ids > 0 ) {
+	  $category_ids = array($catetegory_ids);
+	}
+
+	$allcats = $this->GetCategories();
+	if( !is_array($allcats) || count($allcats) == 0 ) return;
+
+	$tmp = array();
+	foreach( $category_ids as $one ) {
+	  for( $i = 0; $i < count($allcats); $i++ ) {
+		if( $one == $allcats[$i]['category_id'] ) {
+		  $tmp[] = $allcats[$i]['category_name'];
+		  break;
+		}
+	  }
+	}
+	if( count($tmp) > 0 ) return implode(', ',$tmp);
+  }
+
   function ConvertCategoriesToString($categories)
   {
 	$ary = array();
@@ -680,4 +649,4 @@ final class CGCalendar extends CGExtensions
   }
 
 }; // class
-?>
\ No newline at end of file
+?>
