@@ -47,15 +47,11 @@ $categories = $this->GetCategories();
 // Get the event
 $event_id = get_parameter_value($params, 'event_id', -1);
 $event = $this->GetEvent($event_id);
-if( isset($params['do_get_from_params']) && $params['do_get_from_params'] == 1 )
-  {
-    $this->GetEventFromParams($event,$params);
-  }
+if( isset($params['do_get_from_params']) && $params['do_get_from_params'] == 1 ) {
+  $this->GetEventFromParams($event,$params);
+}
 $tmp = cgcalendar_utils::get_username($event['event_created_by']);
-if( $tmp )
-  {
-    $event['owner_name'] = $tmp;
-  }
+if( $tmp ) $event['owner_name'] = $tmp;
 $smarty->assign('event',$event);
 $fields = $this->GetFields();
 
