@@ -41,11 +41,12 @@ if ($this->AllowAccess('Modify Site Preferences')) {
 
     $this->SetCurrentTab('admin_manage_settings');
 
+    $firstdayofweek = get_parameter_value($params,'firstdayofweek');
     $use_twelve_hour_clock = get_parameter_value($params,'use_twelve_hour_clock');
     $force_category = get_parameter_value($params, 'force_category');
     $showpastyears = get_parameter_value($params, 'showpastyears');
     $showfutureyears = get_parameter_value($params, 'showfutureyears');
-    $default_category = get_parameter_value($params, 'default_category');
+    $default_category = get_parameter_value($params, 'default_category','');
     $hidesummary = get_parameter_value($params, 'hidesummary',0);
     $hidecontent = get_parameter_value($params, 'hidecontent',0);
     $uploaddirectory = get_parameter_value($params, 'uploaddirectory');
@@ -61,6 +62,7 @@ if ($this->AllowAccess('Modify Site Preferences')) {
 
     $this->SetPreference('overlap_policy',$overlap_policy);
     $this->SetPreference('overlap_action',$overlap_action);
+    $this->SetPreference('firstdayofweek',$firstdayofweek);
     $this->SetPreference('use_twelve_hour_clock', $use_twelve_hour_clock);
     $this->SetPreference('defaultcalendarpage', $_POST['parent_id']);
     $this->SetPreference('default_category', $default_category);
@@ -85,10 +87,7 @@ if ($this->AllowAccess('Modify Site Preferences')) {
     $start_time = get_parameter_value($params,'dflt_starttime_Hour',12).':'.get_parameter_value($params,'dflt_starttime_Minute',00);
     $this->SetPreference('dflt_starttime',$start_time);
 
-    if( isset($params['frontend_group']) )
-      {
-	$this->SetPreference('frontend_group',$params['frontend_group']);
-      }
+    if( isset($params['frontend_group']) ) $this->SetPreference('frontend_group',$params['frontend_group']);
     $this->SetPreference('frontend_redirectpage',$frontend_redirectpage);
   }
 
