@@ -36,71 +36,51 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 
-{
-  $tmp = $this->GetModuleInstance('Calendar');
-  if( is_object($tmp) )
-    {
-      echo $this->ShowErrors($this->Lang('error_calendar_incompatible'));
-    }
+$tmp = $this->GetModuleInstance('Calendar');
+if( is_object($tmp) ) {
+  echo $this->ShowErrors($this->Lang('error_calendar_incompatible'));
 }
 
 // the top nav bar
-if( $this->CheckPermission('Modify Templates') )
-  {
-    echo '<div class="pageoverflow" style="text-align: right; width: 80%;">';
-    echo $this->CreateImageLink($id,'admin_templates',$returnid,
-				$this->Lang('lbl_templates'),
-				'icons/topfiles/template.gif',array(),'','',false);
-    echo '</div>';
-  }
+if( $this->CheckPermission('Modify Templates') ) {
+  echo '<div class="pageoverflow" style="text-align: right; width: 80%;">';
+  echo $this->CreateImageLink($id,'admin_templates',$returnid,$this->Lang('lbl_templates'),'icons/topfiles/template.gif',array(),'','',false);
+  echo '</div>';
+}
 
 echo $this->StartTabHeaders();
-if( $this->CheckPermission('Modify Calendar') )
-{
-  echo $this->SetTabHeader('defaultadmin', $this->Lang('cal_events'));
-}
-if( $this->CheckPermission('Manage Calendar Attributes') )
-{
+if( $this->CheckPermission('Modify Calendar') ) echo $this->SetTabHeader('defaultadmin', $this->Lang('cal_events'));
+if( $this->CheckPermission('Manage Calendar Attributes') ) {
   echo $this->SetTabHeader('admin_manage_categories', $this->Lang('cal_categories'));
   echo $this->SetTabHeader('fields',$this->Lang('fields'));
 }
-
-if( $this->CheckPermission('Modify Site Preferences') )
-{
-  echo $this->SetTabHeader('admin_manage_settings',$this->Lang('cal_settings'));
-}
+if( $this->CheckPermission('Modify Site Preferences') ) echo $this->SetTabHeader('admin_manage_settings',$this->Lang('cal_settings'));
 echo $this->EndTabHeaders();
 
 
 echo $this->StartTabContent();
-if( $this->CheckPermission('Modify Calendar') )
-{
-	echo $this->StartTab("defaultadmin",$params);
-	{
-		require_once(dirname(__FILE__).'/function.admindisplaymanageevents.php');
-		AdminDisplayManageEvents($this, $id, $params, $returnid);
-	}
-	echo $this->EndTab();
+if( $this->CheckPermission('Modify Calendar') ) {
+  echo $this->StartTab("defaultadmin",$params);
+  require_once(dirname(__FILE__).'/function.admindisplaymanageevents.php');
+  echo $this->EndTab();
 }
 
-if( $this->CheckPermission('Manage Calendar Attributes') )
-{
-	echo $this->StartTab("admin_manage_categories",$params);
-	$this->AdminDisplayCategories($id, $params, $returnid);
-	echo $this->EndTab();
+if( $this->CheckPermission('Manage Calendar Attributes') ) {
+  echo $this->StartTab("admin_manage_categories",$params);
+  $this->AdminDisplayCategories($id, $params, $returnid);
+  echo $this->EndTab();
 
-	echo $this->StartTab("fields",$params);
-	include(dirname(__FILE__).'/function.admin_fieldstab.php');
-	echo $this->EndTab();
+  echo $this->StartTab("fields",$params);
+  include(dirname(__FILE__).'/function.admin_fieldstab.php');
+  echo $this->EndTab();
 }
 
-if( $this->CheckPermission('Modify Site Preferences') )
-{
-	echo $this->StartTab("admin_manage_settings");
-	include(dirname(__FILE__).'/function.admin_settingstab.php');
-	echo $this->EndTab();
+if( $this->CheckPermission('Modify Site Preferences') ) {
+  echo $this->StartTab("admin_manage_settings");
+  include(dirname(__FILE__).'/function.admin_settingstab.php');
+  echo $this->EndTab();
 }
 
 echo $this->EndTabContent();
 
-?>
+?>
\ No newline at end of file
