@@ -1,6 +1,30 @@
 <?php
 # Simple Language file for the Calendar module.
 # Copyright (c) 2004 by Rob Allen <rob@akrabat.com>
+$lang['prompt_general_settings'] = 'General Settings';
+$lang['prompt_editing_settings'] = 'Event Editing Settings';
+$lang['prompt_feedit_settings'] = 'Frontend Editing Settings';
+$lang['prev_month'] = 'Go to the previous month';
+$lang['next_month'] = 'Go to the next month';
+$lang['info_customfields_tab'] = 'Custom fields can be reordered by dragging and dropping rows.  Only text fields are searchable, and only text areas can have WYSIWYG fields attached. <strong style="color: red;">Note:</strong> WYSIWYG fields will not be shown for textarea fields on the frontend.';
+$lang['msg_categories_updated'] = 'Categories updated';
+$lang['msg_fieldsupdated'] = 'Field definitions updated';
+$lang['wysiwyg'] = 'WYSIWYG';
+$lang['info_reorder_categories'] = 'Category order can be defined by dragging and dropping rows';
+$lang['error_categorynamerow'] = 'The name has been erased for a valid category at row:';
+$lang['confirm_nocategories'] = 'We detected no valid categories.  Are you sure that this is what you want to do?';
+$lang['add_field'] = 'Add Field';
+$lang['add_category'] = 'Add Category';
+$lang['prompt_firstdayofweek'] = 'First Day of the Week';
+$lang['edit_event'] = 'Edit event';
+$lang['edit_parent_event'] = 'Edit the parent event';
+$lang['title_child_event'] = 'This is a child of a parent recurring event';
+$lang['select_period'] = 'Period';
+$lang['show_filter'] = 'Show Filter';
+$lang['show_filter_applied'] = 'Show Filter <em>(applied)</em>';
+$lang['reset'] = 'Reset';
+$lang['cal_current'] = 'This Period';
+$lang['cal_from'] = 'From';
 $lang['error_feu_loggedin'] = 'The user is not logged in to FEU.  Adding or editing events is not permitted';
 $lang['prompt_friendlyname'] = 'Friendly Name for this Module in Admin Navigation';
 $lang['info_friendlyname'] = 'Note: You may need to clear the site cache for this preference to have effect.  If no value is supplied a default will be used.';
@@ -71,7 +95,6 @@ $lang['info_dflt_starttime'] = '<em>(applies only if new events are not &quot;Al
 $lang['search_type'] = 'Search Type';
 $lang['search_any'] = 'Return results matching any word';
 $lang['search_all'] = 'Return results matching all words';
-$lang['info_customfields'] = '<span style="color: red;">Note:</span> Only text fields are searchable.  Clicking the chechbox on other field types will have no effect.';
 $lang['searchable'] = 'Searchable';
 $lang['help_param_editeventtemplate'] = 'Applicable only to the myevents action, this parameter allows specifying a non default edit event template to use when a user creates or edits an event';
 $lang['help_param_editpage'] = 'Applicable only to the myevents action, this parameter allows specifying a different page for the edit form.';
@@ -79,8 +102,8 @@ $lang['help_param_myeventstemplate'] = 'Applicable only to the myevents action,
 $lang['cal_edit_event'] = 'Edit Calendar Event';
 $lang['error_dberror'] = 'Database Error';
 $lang['submit'] = 'Submit';
-$lang['info_sysdflt_editevent_template'] = 'System Default &quot;Edit Event&quot; Template';
-$lang['info_sysdflt_myevents_template'] = 'System Default &quot;My Events&quot; Template';
+$lang['info_sysdflt_editevent_template'] = 'Prototype &quot;Edit Event&quot; Template';
+$lang['info_sysdflt_myevents_template'] = 'Prototype &quot;My Events&quot; Template';
 $lang['prompt_feedit_group'] = 'Members of this FEU group can add events';
 $lang['prompt_feedit_page'] = 'Default page for the frontend edit form.';
 $lang['none'] = 'None';
@@ -157,14 +180,14 @@ $lang['last_saturday'] = 'Last Saturday of the Month';
 $lang['error_invalid_recur_monthly_freq'] = 'Invalid frequency.... you cannot specify both the specified date AND other values';
 $lang['searchresulttemplate_addedit'] = 'Add/Edit a Search Result Template';
 $lang['info_searchresult_template_tab'] = 'The list of templates that are available for the search results display';
-$lang['info_sysdflt_searchresult_template'] = 'System Default Search Result Template';
+$lang['info_sysdflt_searchresult_template'] = 'Prototype Search Result Template';
 $lang['cal_search_result_templates'] = 'Search Result Templates';
 $lang['error_query_failed'] = 'Database Query Failed';
 $lang['error_search_invalid_dates'] = 'Invalid Search Dates Specified';
 $lang['text'] = 'Text';
 $lang['search'] = 'Search';
 $lang['category'] = 'Category';
-$lang['info_sysdflt_search_template'] = 'System Default Search Form Template';
+$lang['info_sysdflt_search_template'] = 'Prototype Search Form Template';
 $lang['searchtemplate_addedit'] = 'Add/Edit a Search Form Template';
 $lang['info_search_template_tab'] = 'The list of templates that are available for the search form';
 $lang['cal_search_form_templates'] = 'Search Form Templates';
@@ -224,16 +247,16 @@ $lang['start_date'] = 'Start Date';
 $lang['end_date'] = 'End Date';
 $lang['info_upcominglist_template_tab'] = 'The list of templates that are available for upcominglist views';
 $lang['upcominglisttemplate_addedit'] = 'Add/Edit an Upcominglist Display Template';
-$lang['info_sysdflt_upcominglist_template'] = 'System Default Upcominglist Template';
+$lang['info_sysdflt_upcominglist_template'] = 'Prototype Upcominglist Template';
 $lang['info_list_template_tab'] = 'The list of templates that are available for list views';
 $lang['listtemplate_addedit'] = 'Add/Edit an List Display Template';
-$lang['info_sysdflt_list_template'] = 'System Default List Template';
+$lang['info_sysdflt_list_template'] = 'Prototype List Template';
 $lang['info_event_template_tab'] = 'The list of templates that are available for event views';
 $lang['eventtemplate_addedit'] = 'Add/Edit an Event Display Template';
-$lang['info_sysdflt_event_template'] = 'System Default Event Template';
+$lang['info_sysdflt_event_template'] = 'Prototype Event Template';
 $lang['info_calendar_template_tab'] = 'The list of templates that are available for calendar views';
 $lang['calendartemplate_addedit'] = 'Add/Edit a Calendar Display Template';
-$lang['info_sysdflt_calendar_template'] = 'System Default Calendar Template';
+$lang['info_sysdflt_calendar_template'] = 'Prototype Calendar Template';
 $lang['info_sysdflt_template'] = 'This form defines the template that will be used when you click &quot;New Template&quot; in the appropriate tab.  Changing this value will have no immediate effect on the displays generated from this module.';
 
 # Language: en_US
@@ -307,7 +330,7 @@ $lang['error_csv_insert'] = 'Error importing event from csv at line %d';
 $lang['error_csvfirstlinefldnotfound'] = 'A required field: %s, could not be found in the csv file header line';
 $lang['error_csvinvalidfirstline'] = 'Could not find a valid first line of the CSV file';
 $lang['msg_eventadded'] = 'Event Added';
-$lang['error_noeventname'] = 'A name for the event is required';
+$lang['error_noeventname'] = 'A title for the event is required';
 $lang['error_noupload'] = 'ERROR: No uploaded file found';
 $lang['error_invalidfilename'] = 'ERROR: The file uploaded cannot be accepted';
 $lang['error_problemwithupload'] = 'ERROR: A problem occurred trying to upload the file';
@@ -319,7 +342,7 @@ $lang['error_categoryexists'] = 'ERROR: A category with the name %s already exis
 
 $lang['cal_id'] = 'Id';
 $lang['cal_calendar'] = 'Calguys Calendar';
-$lang['cal_default_templates'] = 'Default Templates';
+$lang['cal_default_templates'] = 'Prototype Templates';
 $lang['cal_description'] = 'Add, edit and remove events';
 $lang['cal_addevent'] = 'Add Event';
 $lang['cal_import_events'] = 'Import Events';
@@ -448,7 +471,7 @@ $lang["description"]="<p>Calendar is a module for displaying events on your page
 		module is installed, a Calendar admin page is added to the content menu
 		that will allow you to manage your events.</p>";
 
-$lang['defaultcalendarpage'] = 'Default page that contains Calendar. This page must contain a Smarty tag that calls Calendar. Required if you use the pretty URLs.';
+$lang['defaultcalendarpage'] = 'Default event view page';
 $lang['uploaddirectory'] = 'Directory where file uploads should be placed';
 $lang['uploadfiletypes'] = 'Allowed file types';
 $lang['uploadunique'] = 'Ensure unique filenames';
