@@ -1,4 +1,19 @@
 <?php
+$lang['msg_categories_updated'] = 'Categorie&euml;n zijn bijgewerkt';
+$lang['msg_fieldsupdated'] = 'Velden zijn bijgewerkt';
+$lang['wysiwyg'] = 'wysiwyg';
+$lang['info_reorder_categories'] = 'De categorie volgorde kan worden gewijzigd door de regels te slepen';
+$lang['add_field'] = 'Veld toevoegen';
+$lang['add_category'] = 'Categorie toevoegen';
+$lang['prompt_firstdayofweek'] = 'Eerste dag van de week';
+$lang['edit_event'] = 'Gebeurtenis wijzigen';
+$lang['edit_parent_event'] = 'Bovenliggende gebeurtenis wijzigen';
+$lang['select_period'] = 'Periode';
+$lang['show_filter'] = 'Toon filter';
+$lang['show_filter_applied'] = 'Toon filter <em>(actief)</em>';
+$lang['reset'] = 'Herstellen';
+$lang['cal_current'] = 'Deze periode';
+$lang['cal_from'] = 'van';
 $lang['error_feu_loggedin'] = 'De gebruiker is niet aangemeld in de FEU module.  Het toevoegen of wijzigen van gebeurtenissen is niet mogelijk';
 $lang['prompt_friendlyname'] = 'Gebruiksvriendelijke naam voor deze module binnen het beheerpaneel';
 $lang['info_friendlyname'] = 'Opmerking: U dient mogelijk de cache te legen om deze instelling te laten werken. Wanneer geen waarde is opgegeven zal een standaardwaarde worden gebruikt.';
@@ -10,64 +25,16 @@ $lang['num_imported'] = 'Aantal aangemaakte events: %d';
 $lang['import_lines'] = 'Aantal regels verwerkt uit het bestand: %d';
 $lang['errors'] = 'Fouten';
 $lang['error_csvfirstlineinvalidfield'] = 'Veld: %s is niet herekend en het is geen specifiek veld';
-$lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
-<ul>
-  <li>General Information:
-   <ul>
-     <li>The file must be an ASCII file with unix, dos, or (hopefully) mac line endings.</li>
-     <li>Comments start with // any characters after this on a line will be ignored (including within quotes.</li>
-     <li>Empty lines are ignore.d</li>
-     <li>Fields are delimited with a , however a , can be used as a value within a field if the field is delimited by double quotes.</li>
-     <li>Rows are delimited by newline chars (as above).</li>
-   </ul>
-  </li>
-  <li>The Field Map:
-   <ul>
-    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
-    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
-    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
-   </ul>
-  </li>
-  <li>The Data Rows:
-   <ul>
-    <li>The start time, title, and description fields must not be empty.</li>
-<li>Start and End Times:</li>
-  <ul>
-   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
-   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
-   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
-   <li>If the end time column is empty, then no end time value will be created in the database.</li>
-  </ul>
-</li>
-<li>Categories
-  <ul>
-   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
-   <li>Category names are case sensitive.</li>
-   <li>Categories are not created if they do not exist.</li>
-  </ul>
-</li>
-<li>Custom Fields:
-  <ul>
-    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
-    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
-    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
-  </ul>
-  </li>
-  </ul>
-</li>
-<li>A sample csv file exists in the modules source code directory.</li>
-</ul>';
 $lang['prompt_csv_file'] = 'Selecteer importbestand';
 $lang['delete'] = 'Verwijder';
 $lang['cd_company'] = 'Company Directory Bedrijf';
 $lang['dflt_urlprefix'] = 'Te gebruiken prefix voor Pretty URLS';
 $lang['dflt_alldayevent'] = 'Nieuwe evenementen beslaan standaard de gehele dag';
 $lang['dflt_starttime'] = 'Standaard starttijd voor nieuwe evenementen';
-$lang['info_dflt_starttime'] = '<em>(alleen van toepassing als nieuwe evenementen niet de gehele dag beslaan.)</em>';
+$lang['info_dflt_starttime'] = '<em>(alleen van toepassing als nieuwe evenementen niet de gehele dag beslaan)</em>';
 $lang['search_type'] = 'Zoek Type';
 $lang['search_any'] = 'E&eacute;n of meer zoektermen moeten overeenkomen';
 $lang['search_all'] = 'Alle zoektermen moeten overeenkomen';
-$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Opmerking:</span> &quot;Bestand Upload Velden&quot; zijn niet doorzoekbaar.';
 $lang['searchable'] = 'Doorzoekbaar';
 $lang['help_param_editeventtemplate'] = 'Alleen toepasbaar in de myevents-bewerking, deze parameter specificeert een niet-standaard evenementsjabloon om te gebruiken wanneer een gebruiker een evenement aanmaakt of wijzigt.';
 $lang['help_param_editpage'] = 'Enkel toepasbaar op de myevents-bewerking, deze parameter specificeert een andere pagina voor de edit-form';
@@ -212,7 +179,6 @@ $lang['n/a'] = 'n.v.t.';
 $lang['recurs_until'] = 'Herhalen tot';
 $lang['parent'] = 'Hoofdgebeurtenis';
 $lang['recur_period'] = 'Herhaal periode';
-$lang['filter'] = 'Filter ';
 $lang['start_date'] = 'Startdatum';
 $lang['end_date'] = 'Einddatum';
 $lang['info_upcominglist_template_tab'] = 'Een overzicht van beschikbare sjablonen voor aankomende gebeurtenissen';
@@ -224,7 +190,7 @@ $lang['info_sysdflt_list_template'] = 'Systeem Standaard Lijstweergave Sjabloon'
 $lang['info_event_template_tab'] = 'Een overzicht van beschikbare sjablonen voor gebeurtenis overzichten';
 $lang['eventtemplate_addedit'] = 'Toevoegen/wijzigen gebeurtenisweergave sjabloon';
 $lang['info_sysdflt_event_template'] = 'Standaard gebeurtenisweergave sjabloon';
-$lang['info_calendar_template_tab'] = 'Een overzicht van beschikbare sjablonen voor Kalender weergaves ';
+$lang['info_calendar_template_tab'] = 'Een overzicht van beschikbare sjablonen voor Kalender weergaves';
 $lang['calendartemplate_addedit'] = 'Toevoegen/wijzigen een Kalenderweergave sjabloon';
 $lang['info_sysdflt_calendar_template'] = 'Standaard kalenderweergave sjabloon';
 $lang['info_sysdflt_template'] = 'Deze sjablonen zijn de standaard waarden die worden getoond als u op de Nieuw Sjabloon&quot; toets klikt in de gewenste tab.  Het wijzigen van deze sjablonen zal daarom ook geen direct gevolg hebben voor uw website.';
@@ -244,8 +210,7 @@ $lang['eventhelp-EventAdded'] = '<p>Verzonden na toevoeging van een kalendergebe
 <li>&quot;event_date_end&quot; - Einddatum/tijd van gebeurtenis</li>
 <li>&quot;event_created_by&quot; - De userid van de auteur</li>
 <li>&quot;event_id&quot; - De id van de gebeurtenis</li>
-</ul>
-';
+</ul>';
 $lang['eventhelp-EventEdited'] = '<p>Verzonden na bewerking van een kalendergebeurtenis.</p>
 <h4>Parameters</h4>
 <ul>
@@ -256,8 +221,7 @@ $lang['eventhelp-EventEdited'] = '<p>Verzonden na bewerking van een kalendergebe
 <li>&quot;event_date_end&quot; - Einddatum/tijd van gebeurtenis</li>
 <li>&quot;event_created_by&quot; - De userid van de auteur</li>
 <li>&quot;event_id&quot; - De id van de gebeurtenis</li>
-</ul>
-';
+</ul>';
 $lang['eventhelp-EventDeleted'] = '<p>Verzonden na verwijdering van een kalendergebeurtenis.</p>
 <h4>Parameters</h4>
 <ul>
@@ -266,24 +230,21 @@ $lang['eventhelp-CategoryAdded'] = '<p>Verzonden na toevoeging van een kalenderg
 <h4>Parameters</h4>
 <ul>
 <li>&quot;category_id - De categorie-ID</li>
-</ul>
-';
+</ul>';
 $lang['eventhelp-CategoryEdited'] = '<p>Verzonden na bewerking van een kalendercategorie.</p>
 <h4>Parameters</h4>
 <ul>
 <li>&quot;category_id&quot; - De categorie-ID</li>
 <li>&quot;category_name&quot; - De categorienaam</li>
 <li>&quot;category_order&quot; - De categoriesorteervolgorde</li>
-</ul>
-';
+</ul>';
 $lang['eventhelp-CategoryDeleted'] = '<p>Verzonden na verwijdering van een kalendercategorie.</p>
 <h4>Parameters</h4>
 <ul>
 <li>&quot;category_id&quot; - De categorie-ID</li>
 <li>&quot;category_name&quot; - De categorienaam</li>
 <li>&quot;category_order&quot; - De categoriesorteervolgorde</li>
-</ul>
-';
+</ul>';
 $lang['error_csv_insert'] = 'Fout bij het importeren van het event uit de csv op regel %d';
 $lang['error_csvfirstlinefldnotfound'] = 'Een vereist veld: %s, kon niet worden gevonden in de eerste regel van het csv-bestand';
 $lang['error_csvinvalidfirstline'] = 'Kan geen geldige eerste regel vinden van het CSV-bestand';
@@ -350,7 +311,7 @@ $lang['cal_update'] = 'Bijwerken';
 $lang['cal_event'] = 'Gebeurtenis';
 $lang['cal_date'] = 'Datum';
 $lang['cal_summary'] = 'Samenvatting';
-$lang['cal_details'] = 'Details ';
+$lang['cal_details'] = 'Details';
 $lang['cal_more'] = 'meer >>';
 $lang['cal_return'] = 'Terug';
 $lang['cal_to'] = 'tot';
@@ -406,7 +367,7 @@ $lang['eventdeleted'] = 'De gebeurtenis is verwijderd';
 $lang['eventupdated'] = 'De gebeurtenis is bijgewerkt';
 $lang['default_page_error'] = 'Fout: Met de toepassing van Pretty URLs moet een een standaard pagina opgeven worden, om de kalender te kunnen gebruiken.';
 $lang['time_at'] = 'om';
-$lang['type'] = 'Type ';
+$lang['type'] = 'Type';
 $lang['name'] = 'Naam';
 $lang['order'] = 'Volgorde';
 $lang['fieldadded'] = 'Veld toegevoegd';
@@ -414,7 +375,7 @@ $lang['fielddeleted'] = 'Veld verwijderd';
 $lang['fields'] = 'Instelbare velden';
 $lang['textfield'] = 'Tekstveld';
 $lang['uploadfield'] = 'Bestand upload veld';
-$lang['description'] = '<p>Kalender is een module om gebeurtenissen op een pagina te tonen. Als de module ge&iuml;nstalleerd is, wordt er een Kalender beheer pagina aan het Inhoud-menu toegevoegd die het beheer van de gebeurtenissen mogelijk maakt.</p>';
+$lang['description'] = '<p>CG Kalender is een module om gebeurtenissen op een pagina te tonen. Als de module ge&iuml;nstalleerd is, wordt er een Kalender beheer pagina aan het Inhoud-menu toegevoegd die het beheer van de gebeurtenissen mogelijk maakt.</p>';
 $lang['defaultcalendarpage'] = 'Standaard pagina die de kalender bevat. Deze pagina moet een Smarty-tag bevatten die de kalender aanroept. Verplicht als u de pretty URL&#039;s gebruikt.';
 $lang['uploaddirectory'] = 'Map waar de ge&uuml;ploade bestanden moeten worden geplaatst';
 $lang['uploadfiletypes'] = 'Toegestane bestandstypen';
@@ -425,11 +386,10 @@ $lang['large_width'] = 'Breedte grote afbeelding';
 $lang['large_height'] = 'Hoogte grote afbeelding';
 $lang['cal_recur_period'] = 'Terugkerend';
 $lang['cal_recur_until'] = 'Terugkerend tot';
-$lang['help_template'] = '<p><b>Print auteursnaam:</b></p>
-<code>Auteur: {$event.authorname}</code>
-';
-$lang['utma'] = '156861353.1374813151.1356888095.1356888095.1356888095.1';
-$lang['utmz'] = '156861353.1356888095.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['help_template'] = '<p><b>Toon auteursnaam:</b></p>
+<code>Auteur: {$event.authorname}</code>';
+$lang['utma'] = '156861353.423918649.1382341730.1382341730.1382341730.1';
+$lang['utmz'] = '156861353.1382341730.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
