@@ -38,6 +38,8 @@
 
 class cgcalendar_utils
 {
+  private function __construct() {}
+
   static public function get_uid_by_username($username,$check_admin = false)
   {
     if( $check_admin )
@@ -202,6 +204,137 @@ class cgcalendar_utils
     return $events;
   }
 
+
+  public static function next_ymd($date_str)
+  {
+    list($yy,$mm,$dd) = self::to_ymd($date_str);
+    if( $dd == '' ) {
+      if( $mm == '' ) {
+	// next year
+	return (int)$yy+1;
+      }
+      else {
+	// next month
+	$mm = (int)$mm+1;
+	if( $mm == 13 ) {
+	  $yy = (int)$yy+1;
+	  $mm = 1;
+	}
+	return "$yy-$mm";
+      }
+    }
+    else {
+      // next day.
+      $dd = (int)$dd+1;
+      $ut = strtotime($date_str);
+      $lastday = date('t',$ut);
+      if( $dd > $lastday ) {
+	$dd = 1;
+	$mm = (int)$mm+1;
+	if( $mm == 13 ) {
+	  $yy = (int)$yy+1;
+	  $mm = 1;
+	}
+      }
+      return "$yy-$mm-$dd";
+    }
+  }
+
+
+  public static function prev_ymd($date_str)
+  {
+    list($yy,$mm,$dd) = self::to_ymd($date_str);
+    if( $dd == '' ) {
+      if( $mm == '' ) {
+	// prev year
+	return (int)$yy-1;
+      }
+      else {
+	// prev month
+	$mm = (int)$mm-1;
+	if( $mm < 1 ) {
+	  // wrapping years
+	  $yy = (int)$yy-1;
+	  $mm = 12;
+	}
+	return "$yy-$mm";
+      }
+    }
+    else {
+      // prev day.
+      $dd = (int)$dd-1;
+      if( $dd < 1 ) {
+	$mm = (int)$mm-1;
+	if( $mm < 1 ) {
+	// wrapping years
+	  $yy = (int)$yy-1;
+	  $mm = 12;
+	  $dd = 31;
+	}
+	else {
+	  $dd = date('t',strtotime("$yy-$mm-2"));
+	}
+      }
+      return "$yy-$mm-$dd";
+    }
+  }
+
+
+  public static function to_ymd($str)
+  {
+    $tmp = explode(' ',$str);
+    $tmp = $tmp[0];
+    $tmp = explode('-',$tmp);
+    for( $i = count($tmp); $i < 3; $i++ ) {
+      $tmp[$i] = '';
+    }
+    return $tmp;
+  }
+
+
+  public static function get_query($start,$end,$category,$reverse)
+  {
+    $module = cms_utils::get_module('CGCalendar');
+    $sorting = ($reverse == true ? 'DESC' : 'ASC');
+    $events_table_name = $module->events_table_name;
+    $categories_table_name = $module->categories_table_name;
+    $events_to_categories_table_name = $module->events_to_categories_table_name;
+
+    $db = cmsms()->GetDb();
+    if( is_int($start) ) $start = $db->DbTimeStamp($start);
+    if( is_int($end) ) $end = $db->DbTimeStamp($end);
+
+    $sql = "SELECT DISTINCT E.event_id FROM $events_table_name E\n";
+
+    if($category) {
+      $sql .= "INNER JOIN $events_to_categories_table_name EC ON E.event_id = $EC.event_id
+	       INNER JOIN $categories_table_name ON $EC.category_id = $categories_table_name.category_id";
+    }
+
+    $sql .= "WHERE ( (E.event_date_start BETWEEN $start AND $end) OR (E.event_date_end BETWEEN $start AND $end) )";
+    $sql .= "OR (E.event_date_start <= $start AND E.event_date_end > $end)\n";
+
+    if( $category ) {
+      $cats = explode(',', $category);
+      $tmp = array();
+      foreach($cats as $cat) {
+	$cat = trim($cat);
+	$tmp[] = "$categories_table_name.category_name LIKE '$cat'";
+      }
+      $sql .= ' AND '.implode(' AND ',$tmp);
+    }
+    $sql .= " ORDER BY E.event_date_start $sorting";
+    return $sql;
+  }
+
+  public static function get_sessionkey($params)
+  {
+    $badkeys = array('returnid','page','year','month','day','date','week','pastitems');
+    foreach($badkeys as $one) {
+      unset($params[$one]);
+    }
+    return md5(serialize($params));
+  }
 } // end of class
 
 #
